var Sprig = function(x, y){
    this.x = x;
    this.y = y;
    this.moveX = 0;
    this.moveY = 0;
    this.visible = true;
};
var Sprite = function(imgSrc, x, y){
    Sprig.call(this, x, y);
    this.img = new Image();
    this.img.src = imgSrc;
    this.continuous = false;
};
Sprite.prototype.animate = function() {
    if(this.visible){
        ctx.drawImage(this.img, this.x, this.y);
    }
    if(game.state === game.states.running || game.state === game.states.over){
        this.x += this.moveX;
        this.y += this.moveY;
        if(this.continuous && this.x < (canvas.width - this.img.width)){
            this.x = 0;
        }
    }
};
Sprite.prototype.getRect = function(){
    return {x: this.x, y: this.y, width: this.img.width, height: this.img.height};
};
var Anim = function(imgSrc, frames, frameWidth, repeat){
    this.img = new Image();
    this.img.src = imgSrc;
    this.frames = frames;
    this.frameWidth = frameWidth;
    this.frame = -1;
    this.default = 0;
    this.repeat = repeat;
    this.reset = function(){this.frame = -1;};
};
Anim.prototype.animate = function(x, y) {
    if(game.state == game.states.running){
        if(this.repeat){
            this.frame++;
            this.frame %= this.frames;
        } else {
            if(this.frame < this.frames -1){
                this.frame++;
            }
        }
    } else {
        this.frame = this.default; // stop animation
    }
    let clipx = this.frame * this.frameWidth;
    ctx.drawImage(this.img, clipx, 0, this.frameWidth, this.img.height, x, y, this.frameWidth, this.img.height);
};
Anim.prototype.getRect = function(x, y){
    return {x: x, y: y, width: this.frameWidth, height: this.img.height};
};
var Actor = function(x, y){
    Sprig.call(this, x, y);
    this.anims = [];
    this.current = 0;
    this.height = 0;
    this.resetCurrent = function(newVal){
        this.current = newVal;
        this.anims[this.current].reset();
    };
};
Actor.prototype.manageActions = function() {};
Actor.prototype.animate = function() {
    if(this.visible){
        this.anims[this.current].animate(this.x, this.y);
    }
    if(game.state == game.states.running){
        this.x += this.moveX;
        this.y += this.moveY;
    }
    this.manageActions();
};
Actor.prototype.getRect = function(){
    return this.anims[this.current].getRect(this.x, this.y);
};